@@ -1325,12 +1325,12 @@ def test_dctrl_lint_obsolete_fields(
     Maintainer: Jane Developer <jane@example.com>
     Build-Depends: debhelper-compat (= 13),
     DM-Upload-Allowed: yes
-    X-Python-Version: 2.7
     Rules-Requires-Root: no
     Homepage: https://example.com
 
     Package: foo
     Architecture: all
+    XB-Important: yes
     Description: some short synopsis
      A very interesting description
      with a valid synopsis
@@ -1351,11 +1351,11 @@ def test_dctrl_lint_obsolete_fields(
     assert f"{first_issue.range}" == "6:0-7:0"
     assert first_issue.severity == DiagnosticSeverity.Warning
 
-    msg_2 = '"X-Python-Version" has been replaced by "X-Python3-Version"'
+    msg_2 = '"XB-Important" has been replaced by "Protected"'
     problem_text_2 = diag_range_to_text(lines, second_issue.range)
     assert second_issue.message == msg_2
-    assert problem_text_2 == "X-Python-Version"
-    assert f"{second_issue.range}" == "7:0-7:16"
+    assert problem_text_2 == "XB-Important"
+    assert f"{second_issue.range}" == "12:0-12:12"
     assert second_issue.severity == DiagnosticSeverity.Warning
 
 
